package com.greenorange.promotion.model.dto.fileInfo;

import com.greenorange.promotion.annotation.FileEnumValue;
import com.greenorange.promotion.model.enums.FileUploadBizEnum;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Min;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;

/**
 * 文件更新请求体
 */
@Data
@Schema(description = "文件更新请求体", requiredProperties = {
                "id",
                "name",
                "type",
                "size",
                "fileView",
                "biz",
})
public class FileInfoUpdateRequest implements Serializable {

    /**
     * 文件ID
     */
    @Min(value = 1L, message = "文件ID ID不能小于1")
    @Schema(description = "文件ID", example = "1")
    private Long id;

    /**
     * 文件名
     */
    @NotBlank(message = "文件名不能为空")
    @Schema(description = "文件名", example = "file.png")
    private String name;

    /**
     * 文件类型
     */
    @NotBlank(message = "文件类型不能为空")
    @Schema(description = "文件类型", example = "png")
    private String type;

    /**
     * 文件大小(KB)
     */
    @Min(value = 1L, message = "文件大小 ID不能小于1")
    @Schema(description = "文件大小", example = "3000")
    private Double size;

    /**
     * 文件view值
     */
    @NotBlank(message = "文件view值不能为空")
    @Schema(description = "文件view值", example = "3E8U2AM8")
    private String fileView;

    /**
     * 文件业务类型[头像(avatar)|项目(project)|富文本(richText)|默认(default))]
     */
    @FileEnumValue(enumClass = FileUploadBizEnum.class)
    @Schema(description = "文件业务类型[头像(avatar)|项目(project)|富文本(richText)|默认(default))]", example = "default")
    private String biz;

    /**
     * 文件hash值
     */
    @NotBlank(message = "文件hash值不能为空")
    @Schema(description = "文件hash值", example = "3E8U2AM8")
    private String hashValue;


    @Serial
    private static final long serialVersionUID = 1L;
}