package com.greenorange.promotion.model.dto.fundsChange;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Min;
import lombok.Data;
import java.math.BigDecimal;

import java.io.Serial;
import java.io.Serializable;
import com.greenorange.promotion.common.PageRequest;

/**
 * 资金变动记录查询请求体，继承自分页请求 PageRequest
 */
@Data
@Schema(description = "资金变动记录查询请求体", requiredProperties = {"current", "pageSize"})
public class FundsChangeQueryRequest extends PageRequest implements Serializable {

    /**
     * 资金变动ID
     */
    @Min(value = 1L, message = "资金变动ID ID不能小于1")
    @Schema(description = "资金变动ID", example = "1")
    private Long id;

    /**
     * 项目名称
     */
    @Schema(description = "项目名称", example = "饿了么-超吃卡")
    private String projectName;

    /**
     * 变动金额
     */
    @Schema(description = "变动金额", example = "0.96")
    private BigDecimal changeAmount;

    /**
     * 当前金额（变动后的总金额）
     */
    @Schema(description = "当前金额（变动后的总金额）", example = "0.34")
    private BigDecimal currentAmount;

    /**
     * 用户ID
     */
    @Min(value = 1L, message = "用户ID ID不能小于1")
    @Schema(description = "用户ID", example = "1")
    private Long userId;

    /**
     * 项目结算记录ID
     */
    @Min(value = 1L, message = "项目结算记录ID ID不能小于1")
    @Schema(description = "项目结算记录ID", example = "1")
    private Long projectSettlementId;


    @Serial
    private static final long serialVersionUID = 1L;
}

