package com.greenorange.promotion.model.dto.userInfo;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Size;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;

/**
 * 小程序用户注册请求体
 */
@Data
@Schema(description = "小程序用户注册请求体", requiredProperties = {"nickName", "phoneNumber",
"verificationCode", "invitationCode", "userPassword"})
public class UserInfoRegisterRequest implements Serializable {

    /**
     * 用户昵称
     */
    @NotBlank(message = "用户昵称不能为空")
    @Schema(description = "用户昵称", example = "chenxinzhi")
    private String nickName;

    /**
     * 手机号
     */
    @NotBlank(message = "手机号不能为空")
    @Schema(description = "手机号", example = "15888610253")
    private String phoneNumber;

    /**
     * 验证码
     */
    @NotBlank(message = "验证码不能为空")
    @Schema(description = "验证码", example = "666999")
    private String verificationCode;

    /**
     * 邀请码
     */
    @Schema(description = "邀请码", example = "666999")
    private String invitationCode;

    /**
     * 密码
     */
    @NotBlank(message = "密码不能为空")
    @Size(min = 6, max = 10, message = "密码长度在 6 到 10 个字符")
    @Schema(description = "密码（建议加密存储）", example = "qingcheng")
    private String userPassword;


    @Serial
    private static final long serialVersionUID = 1L;
}
